@@ -37,7 +37,7 @@ def get_database_migration_plugin(app: "Litestar") -> "SQLAlchemyInitPlugin":
     raise ImproperConfigurationError(msg)
 
 
-@click.group(cls=LitestarGroup, name="database")
+@click.group(cls=LitestarGroup, name="database", aliases=["db"])
 def database_group(ctx: "click.Context") -> None:
     """Manage SQLAlchemy database components."""
     ctx.obj = {"app": ctx.obj, "configs": get_database_migration_plugin(ctx.obj.app).config}
